KUPP
====
KUPP (KEEN Universe PreProcessor) is a Python package for preprocessing a knowledge graph.

Installation |pypi_version| |python_versions| |pypi_license|
------------------------------------------------------------


.. |python_versions| image:: https://img.shields.io/pypi/pyversions/kupp.svg
    :alt: Stable Supported Python Versions

.. |pypi_version| image:: https://img.shields.io/pypi/v/kupp.svg
    :alt: Current version on PyPI

.. |pypi_license| image:: https://img.shields.io/pypi/l/kupp.svg
    :alt: MIT License
